==> apache-calcite-1.19.0-src.tar.gz: apache-calcite-1.19.0-src/core/src/main/java/org/apache/calcite/rex/RexVariable.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.calcite.rex;

import org.apache.calcite.rel.type.RelDataType;

import java.util.Objects;

/**
 * A row-expression which references a field.
 */
public abstract class RexVariable extends RexNode {
  //~ Instance fields --------------------------------------------------------

  protected final String name;
  protected final RelDataType type;

  //~ Constructors -----------------------------------------------------------

  protected RexVariable(
      String name,
      RelDataType type) {
    this.name = Objects.requireNonNull(name);
    this.digest = Objects.requireNonNull(name);
    this.type = Objects.requireNonNull(type);
  }

  //~ Methods ----------------------------------------------------------------

  public RelDataType getType() {
    return type;
  }

  /**
   * Returns the name of this variable.
   */
  public String getName() {
    return name;
  }
}

// End RexVariable.java

==> apache-calcite-1.37.0-src.tar.gz: apache-calcite-1.37.0-src/core/src/main/java/org/apache/calcite/rex/RexVariable.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.calcite.rex;

import org.apache.calcite.rel.type.RelDataType;

import java.util.Objects;

/**
 * A row-expression which references a field.
 */
public abstract class RexVariable extends RexNode {
  //~ Instance fields --------------------------------------------------------

  protected final String name;
  protected final RelDataType type;

  //~ Constructors -----------------------------------------------------------

  protected RexVariable(
      String name,
      RelDataType type) {
    this.name = Objects.requireNonNull(name, "name");
    this.digest = Objects.requireNonNull(name, "name");
    this.type = Objects.requireNonNull(type, "type");
  }

  //~ Methods ----------------------------------------------------------------

  @Override public RelDataType getType() {
    return type;
  }

  /**
   * Returns the name of this variable.
   */
  public String getName() {
    return name;
  }
}
